'use client';
import * as React from 'react';
import { ThemeProvider as NextThemesProvider } from 'next-themes';
import { Moon, Sun } from 'lucide-react';
import { useTheme } from 'next-themes';
import { Button } from '@/components/ui';

export const ThemeProvider = ({
  children,
  ...props
}: React.ComponentProps<typeof NextThemesProvider>) => {
  const [mounted, setMounted] = React.useState(false);

  React.useEffect(() => {
    setMounted(true);
  }, []);

  if (!mounted) return null;

  return <NextThemesProvider {...props}>{children}</NextThemesProvider>;
};

type ThemeToggleProps = React.ButtonHTMLAttributes<HTMLButtonElement> & {
  size?: number;
};

export const ThemeToggle = ({ size = 1, ...props }: ThemeToggleProps) => {
  const { setTheme, resolvedTheme } = useTheme();
  const [mounted, setMounted] = React.useState(false);

  React.useEffect(() => {
    setMounted(true);
  }, []);

  if (!mounted) {
    return (
      <Button variant='outline' size='icon' {...props}>
        <span style={{ height: `${size}rem`, width: `${size}rem` }} />
      </Button>
    );
  }

  const toggleTheme = () => {
    if (resolvedTheme === 'dark') setTheme('light');
    else setTheme('dark');
  };

  return (
    <Button
      variant='outline'
      size='icon'
      className='cursor-pointer'
      onClick={toggleTheme}
      {...props}
    >
      <Sun
        style={{ height: `${size}rem`, width: `${size}rem` }}
        className='rotate-0 scale-100 transition-all dark:-rotate-90 dark:scale-0'
      />
      <Moon
        style={{ height: `${size}rem`, width: `${size}rem` }}
        className='absolute rotate-90 scale-0 transition-all dark:rotate-0 dark:scale-100'
      />
      <span className='sr-only'>Toggle theme</span>
    </Button>
  );
};
